==> nextcloud-app-mail-0.7.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/tr.js <==
OC.L10N.register(
    "mail",
    {
    "Mail" : "Posta",
    "Loading accounts …" : "Hesaplar yükleniyor...",
    "Error while loading the accounts." : "Hesaplar yüklenirken sorun çıktı.",
    "Error while loading the selected account." : "Seçilmiş hesap yüklenirken sorun çıktı.",
    "Can not load this folder." : "Bu klasör yüklenemedi.",
    "Loading {folder}" : "{folder} yükleniyor",
    "Searching for {query}" : "{query} aranıyor",
    "Error while deleting message." : "İleti silinirken sorun çıktı.",
    "Forwarded message" : "İletilmiş ileti",
    "Choose a folder to store the attachment in" : "Ek dosyasının depolanacağı bir klasör seçin",
    "Attachments saved to Files." : "Ek Dosya Dosyalara kaydedildi.",
    "Attachment saved to Files." : "Ek Dosya Dosyalara kaydedildi.",
    "Error while saving attachments to Files." : "Ek dosyalar Dosyalara kaydedilirken sorun çıktı.",
    "Error while saving attachment to Files." : "Ek dosya Dosyalara kaydedilirken sorun çıktı.",
    "Message flag could not be set." : "İleti işareti ayarlanamadı.",
    "Could not move message." : "İleti taşınamadı.",
    "Invalid account" : "Hesap geçersiz",
    "Invalid folder" : "Klasör geçersiz",
    "Error while creating the account: " : "Hesap eklenirken sorun çıktı:",
    "Unknown error" : "Bilinmeyen bir sorun çıktı",
    "All inboxes" : "Tüm gelen kutuları",
    "you" : "siz",
    "Send message to {email}" : "{email} adresine ileti gönder",
    "Could not load {tag}{name}{endtag}" : "{tag}{name}{endtag} yüklenemedi",
    "We couldn’t load {tag}{name}{endtag}" : "{tag}{name}{endtag} yüklenemedi",
    "There was a problem loading {tag}{name}{endtag}" : "{tag}{name}{endtag} yüklenirken bir sorun çıktı",
    "We couldn’t load your message" : "İletiniz yüklenemedi",
    "Unable to load the desired message" : "İstenilen ileti yüklenemedi",
    "There was a problem loading the message" : "İleti yüklenirken bir sorun çıktı",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n yeni ileti\ngönderen {from}","%n yeni ileti\ngönderen {from}"],
    "Nextcloud Mail" : "Nextcloud Posta",
    "Show all folders" : "Tüm klasörleri görüntüle",
    "Collapse folders" : "Klasörleri daralt",
    "Error while deleting account." : "Hesap silinirken sorun çıktı.",
    "Choose a file to add as attachment" : "Eklenecek ek dosyasını seçin",
    "An error occurred while uploading {fname}" : "{fname} yüklenirken bir sorun çıktı",
    "Reply" : "Yanıtla",
    "Send" : "Gönder",
    "Sending …" : "Gönderiliyor...",
    "Message sent!" : "İleti gönderildi!",
    "Server error" : "Sunucu sorunu",
    "An unknown error occurred" : "Bilinmeyen bir sorun çıktı",
    "Opening HTML drafts is not supported yet." : "HTML taslaklarının açılması henüz desteklenmiyor.",
    "Draft saved!" : "Taslak kaydedildi!",
    "No writable calendars found" : "Yazılabilecek bir takvim bulunamadı",
    "Error while importing the calendar event" : "Takvim etkinliği içe aktarılırken sorun çıktı",
    "Error while downloading calendar event" : "Takvim etkinliği indirilirken sorun çıktı",
    "Error while loading messages." : "İletiler yüklenirken sorun çıktı.",
    "Error while refreshing messages." : "İletiler yenilenirken sorun çıktı.",
    "Setting up your account" : "Hesabınız ayarlanıyor",
    "Inbox" : "Gelen Kutusu",
    "Sent" : "Gönderilenler",
    "Drafts" : "Taslaklar",
    "Archive" : "Arşiv",
    "Trash" : "Çöp Kutusu",
    "Junk" : "Gereksiz",
    "All" : "Tümü",
    "Favorites" : "Sık Kullanılanlar",
    "Creating account failed: " : "Hesap oluşturulamadı:",
    "Auto detect failed. Please use manual mode." : "Otomatik olarak algılanamadı. Lütfen el ile kipini kullanın.",
    "Delete permanently" : "Kalıcı olarak sil",
    "& others" : "ve diğer",
    "Error loading message" : "İleti yüklenirken sorun çıktı",
    "Settings" : "Ayarlar",
    "Forwarding to %s" : "%s adresine iletiliyor",
    "Click here if you are not automatically redirected within the next few seconds." : "Bir kaç saniye içinde otomatik olarak yönlendirilmezseniz buraya tıklayın.",
    "Redirect" : "Yönlendir",
    "The link leads to %s" : "Bağlantı %s adresine gidiyor",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Bu sayfayı ziyaret etmek istemiyorsanız, <a href=\"%s\">posta uygulamasına</a> geri dönebilirsiniz.",
    "Continue to %s" : "%s sayfasına geç",
    "Delete account" : "Hesabı sil",
    "Try again" : "Yeniden deneyin",
    "New message" : "Yeni ileti",
    "Account Settings" : "Hesap Ayarları",
    "Aliases" : "Kısaltmalar",
    "Mail address" : "Posta adresi",
    "Display Name" : "Görüntülenecek Ad",
    "Save" : "Kaydet",
    "Keyboard shortcuts" : "Tuş takımı kısayolları",
    "Speed up your Mail experience with these quick shortcuts." : "Kısayol tuşlarını kullanarak e-posta deneyiminizi hızlandırabilirsiniz.",
    "Compose new message" : "Yeni ileti gönder",
    "Newer message" : "Daha yeni ileti",
    "Older message" : "Daha eski ileti",
    "Toggle star" : "Yıldızı değiştir",
    "Toggle unread" : "Okunmamış işaretini değiştir",
    "Delete" : "Sil",
    "Search" : "Arama",
    "Refresh" : "Yenlle",
    "Connect your mail account" : "Posta hesabınızı bağlayın",
    "Name" : "Ad",
    "Mail Address" : "Posta Adresi",
    "Password" : "Parola",
    "Manual configuration" : "El ile yapılandırma",
    "IMAP Host" : "IMAP Sunucusu",
    "IMAP security" : "IMAP Güvenliği",
    "None" : "Yok",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP Kapı Numarası",
    "IMAP User" : "IMAP Kullanıcı Adı",
    "IMAP Password" : "IMAP Parolası",
    "SMTP Host" : "SMTP Sunucusu",
    "SMTP security" : "SMTP Güvenliği",
    "SMTP Port" : "SMTP Kapı Numarası",
    "SMTP User" : "SMTP Kullanıcı Adı",
    "SMTP Password" : "SMTP Parolası",
    "Connect" : "Bağlan",
    "from" : "kimden",
    "to" : "kime",
    "cc" : "kopya",
    "bcc" : "gizli kopya",
    "Subject" : "Konu",
    "Save all to Files" : "Tümünü dosyalara kaydet",
    "Add mail account" : "Posta hesabi ekle",
    "No search results for" : "Şu aramadan bir sonuç alınamadı",
    "The images have been blocked to protect your privacy." : "Gizliliğinizi korumak için görsellerin görüntülenmesi engellendi.",
    "Show images from this sender" : "Bu gönderenden gelen görseller görüntülensin",
    "Forward" : "İlet",
    "Add attachment" : "Dosya ekle",
    "Add from Files" : "Dosyalardan ekle",
    "Import into calendar" : "Şu takvimin içine aktar",
    "Download attachment" : "Ek dosyayı indir",
    "Save to Files" : "Dosyalara Kaydet"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-app-mail-0.7.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/tr.js <==
OC.L10N.register(
    "mail",
    {
    "Mail" : "Posta",
    "Loading accounts" : "Hesaplar yükleniyor",
    "Error while loading the accounts." : "Hesaplar yüklenirken sorun çıktı.",
    "Error while loading the selected account." : "Seçilmiş hesap yüklenirken sorun çıktı.",
    "Can not load this folder." : "Bu klasör yüklenemedi.",
    "Searching for {query}" : "{query} aranıyor",
    "Error while deleting message." : "İleti silinirken sorun çıktı.",
    "Forwarded message" : "İletilmiş ileti",
    "Choose a folder to store the attachment in" : "Ek dosyasının depolanacağı bir klasör seçin",
    "Attachments saved to Files." : "Ek Dosya Dosyalara kaydedildi.",
    "Attachment saved to Files." : "Ek Dosya Dosyalara kaydedildi.",
    "Error while saving attachments to Files." : "Ek dosyalar Dosyalara kaydedilirken sorun çıktı.",
    "Error while saving attachment to Files." : "Ek dosya Dosyalara kaydedilirken sorun çıktı.",
    "Message flag could not be set." : "İleti işareti ayarlanamadı.",
    "Could not move message." : "İleti taşınamadı.",
    "Invalid account" : "Hesap geçersiz",
    "Invalid folder" : "Klasör geçersiz",
    "Error while creating the account: " : "Hesap eklenirken sorun çıktı:",
    "Unknown error" : "Bilinmeyen bir sorun çıktı",
    "All inboxes" : "Tüm gelen kutuları",
    "you" : "siz",
    "Send message to {email}" : "{email} adresine ileti gönder",
    "Could not load {tag}{name}{endtag}" : "{tag}{name}{endtag} yüklenemedi",
    "We couldn’t load {tag}{name}{endtag}" : "{tag}{name}{endtag} yüklenemedi",
    "There was a problem loading {tag}{name}{endtag}" : "{tag}{name}{endtag} yüklenirken bir sorun çıktı",
    "We couldn’t load your message" : "İletiniz yüklenemedi",
    "Unable to load the desired message" : "İstenilen ileti yüklenemedi",
    "There was a problem loading the message" : "İleti yüklenirken bir sorun çıktı",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n yeni ileti\ngönderen {from}","%n yeni ileti\ngönderen {from}"],
    "Nextcloud Mail" : "Nextcloud Posta",
    "Show all folders" : "Tüm klasörleri görüntüle",
    "Collapse folders" : "Klasörleri daralt",
    "Error while deleting account." : "Hesap silinirken sorun çıktı.",
    "Choose a file to add as attachment" : "Eklenecek ek dosyasını seçin",
    "An error occurred while uploading {fname}" : "{fname} yüklenirken bir sorun çıktı",
    "Reply" : "Yanıtla",
    "Send" : "Gönder",
    "Sending …" : "Gönderiliyor...",
    "Message sent!" : "İleti gönderildi!",
    "Server error" : "Sunucu sorunu",
    "An unknown error occurred" : "Bilinmeyen bir sorun çıktı",
    "Opening HTML drafts is not supported yet." : "HTML taslaklarının açılması henüz desteklenmiyor.",
    "Draft saved!" : "Taslak kaydedildi!",
    "No writable calendars found" : "Yazılabilecek bir takvim bulunamadı",
    "Error while importing the calendar event" : "Takvim etkinliği içe aktarılırken sorun çıktı",
    "Error while downloading calendar event" : "Takvim etkinliği indirilirken sorun çıktı",
    "Error while loading messages." : "İletiler yüklenirken sorun çıktı.",
    "Error while refreshing messages." : "İletiler yenilenirken sorun çıktı.",
    "Setting up your account" : "Hesabınız ayarlanıyor",
    "Inbox" : "Gelen Kutusu",
    "Sent" : "Gönderilenler",
    "Drafts" : "Taslaklar",
    "Archive" : "Arşiv",
    "Trash" : "Çöp Kutusu",
    "Junk" : "Gereksiz",
    "All" : "Tümü",
    "Favorites" : "Sık Kullanılanlar",
    "Auto detect failed. Please use manual mode." : "Otomatik olarak algılanamadı. Lütfen el ile kipini kullanın.",
    "Creating account failed: " : "Hesap oluşturulamadı:",
    "Delete permanently" : "Kalıcı olarak sil",
    "& others" : "ve diğer",
    "Error loading message" : "İleti yüklenirken sorun çıktı",
    "Settings" : "Ayarlar",
    "Forwarding to %s" : "%s adresine iletiliyor",
    "Click here if you are not automatically redirected within the next few seconds." : "Bir kaç saniye içinde otomatik olarak yönlendirilmezseniz buraya tıklayın.",
    "Redirect" : "Yönlendir",
    "The link leads to %s" : "Bağlantı %s adresine gidiyor",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Bu sayfayı ziyaret etmek istemiyorsanız, <a href=\"%s\">posta uygulamasına</a> geri dönebilirsiniz.",
    "Continue to %s" : "%s sayfasına geç",
    "Delete account" : "Hesabı sil",
    "Try again" : "Yeniden deneyin",
    "New message" : "Yeni ileti",
    "Account Settings" : "Hesap Ayarları",
    "Aliases" : "Kısaltmalar",
    "Mail address" : "Posta adresi",
    "Display Name" : "Görüntülenecek Ad",
    "Save" : "Kaydet",
    "Keyboard shortcuts" : "Tuş takımı kısayolları",
    "Speed up your Mail experience with these quick shortcuts." : "Kısayol tuşlarını kullanarak e-posta deneyiminizi hızlandırabilirsiniz.",
    "Compose new message" : "Yeni ileti gönder",
    "Newer message" : "Daha yeni ileti",
    "Older message" : "Daha eski ileti",
    "Toggle star" : "Yıldızı değiştir",
    "Toggle unread" : "Okunmamış işaretini değiştir",
    "Delete" : "Sil",
    "Search" : "Arama",
    "Refresh" : "Yenlle",
    "Connect your mail account" : "Posta hesabınızı bağlayın",
    "Name" : "Ad",
    "Mail Address" : "Posta Adresi",
    "Password" : "Parola",
    "Manual configuration" : "El ile yapılandırma",
    "IMAP Host" : "IMAP Sunucusu",
    "IMAP security" : "IMAP Güvenliği",
    "None" : "Yok",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP Kapı Numarası",
    "IMAP User" : "IMAP Kullanıcı Adı",
    "IMAP Password" : "IMAP Parolası",
    "SMTP Host" : "SMTP Sunucusu",
    "SMTP security" : "SMTP Güvenliği",
    "SMTP Port" : "SMTP Kapı Numarası",
    "SMTP User" : "SMTP Kullanıcı Adı",
    "SMTP Password" : "SMTP Parolası",
    "Connect" : "Bağlan",
    "from" : "kimden",
    "to" : "kime",
    "cc" : "kopya",
    "bcc" : "gizli kopya",
    "Subject" : "Konu",
    "Save all to Files" : "Tümünü dosyalara kaydet",
    "Add mail account" : "Posta hesabi ekle",
    "No search results for" : "Şu aramadan bir sonuç alınamadı",
    "The images have been blocked to protect your privacy." : "Gizliliğinizi korumak için görsellerin görüntülenmesi engellendi.",
    "Show images from this sender" : "Bu gönderenden gelen görseller görüntülensin",
    "Forward" : "İlet",
    "No messages in this folder!" : "Bu klasörde herhangi bir ileti yok!",
    "Upload attachment" : "Ek dosya yükle",
    "Add attachment from Files" : "Dosyalardan ek dosya ekle",
    "Import into calendar" : "Şu takvimin içine aktar",
    "Download attachment" : "Ek dosyayı indir",
    "Save to Files" : "Dosyalara Kaydet"
},
"nplurals=2; plural=(n > 1);");
